@@ -155,14 +155,16 @@ int fsys::stat(struct stat *buf)
 
 int fsys::changeDir(const char *path)
 {
-	if(_chdir(path))
+	if (_chdir(path))
 		return remapError();
 	return 0;
 }
 
 char *fsys::getPrefix(char *path, size_t len)
 {
-	return _getcwd(path, len);
+	if (_getcwd(path, len))
+		return remapError();
+	return 0;
 }
 
 int fsys::change(const char *path, unsigned mode)
@@ -297,7 +299,7 @@ void fsys::open(const char *path, access_t access)
 
 	fd = CreateFile(path, amode, smode, NULL, OPEN_EXISTING, attr, NULL);
 	if(fd != INVALID_HANDLE_VALUE && append)
-		seek(end);
+		seek(end)
 	else
 		error = remapError();
 }
@@ -406,11 +408,13 @@ void fsys::operator=(const fsys& from)
 	}
 }
 
-void fsys::drop(offset_t size)
+int fsys::drop(offset_t size)
 {
+	error = ENOSYS;
+	return ENOSYS; 
 }
 
-void fsys::seek(offset_t pos)
+int fsys::seek(offset_t pos)
 {
 	DWORD rpos = pos;
 	int mode = FILE_BEGIN;
@@ -419,8 +423,11 @@ void fsys::seek(offset_t pos)
 		rpos = 0;
 		mode = FILE_END;
 	}
-	if(SetFilePointer(fd, rpos, NULL, mode) == INVALID_SET_FILE_POINTER)
+	if(SetFilePointer(fd, rpos, NULL, mode) == INVALID_SET_FILE_POINTER) {
 		error = remapError();
+		return error;
+	}
+	return 0;
 }
 
 #else
@@ -458,7 +465,9 @@ int fsys::sync(void)
 	int rtn = ::fsync(fd);
 	if(rtn < 0)
 		error = remapError();
-	return rtn;
+	else
+		return 0;
+	return error;
 }
 
 ssize_t fsys::write(const void *buf, size_t len)
@@ -597,15 +606,18 @@ void fsys::open(const char *path, access_t access)
 
 int fsys::stat(const char *path, struct stat *ino)
 {
-	return ::stat(path, ino);
+	if(::stat(path, ino))
+		return remapError();
+	return 0;
 }
 
 int fsys::stat(struct stat *ino)
 {
-	int rtn = ::fstat(fd, ino);
-	if(rtn)
+	if(::fstat(fd, ino)) {
 		error = remapError();
-	return rtn;
+		return error;
+	}
+	return 0;
 }
 
 int fsys::changeDir(const char *path)
@@ -615,9 +627,11 @@ int fsys::changeDir(const char *path)
 	return 0;
 }
 
-char *fsys::getPrefix(char *path, size_t len)
+int fsys::getPrefix(char *path, size_t len)
 {
-	return ::getcwd(path, len);
+	if(::getcwd(path, len))
+		return remapError();
+	return 0;
 }
 
 int fsys::change(const char *path, unsigned mode)
@@ -668,14 +682,21 @@ void fsys::operator=(const fsys& from)
 	}
 }
 
-void fsys::drop(offset_t size)
+int fsys::drop(offset_t size)
 {
 #ifdef	HAVE_POSIX_FADVISE
-	posix_fadvise(fd, (off_t)0, size, POSIX_FADV_DONTNEED);
+	if(posix_fadvise(fd, (off_t)0, size, POSIX_FADV_DONTNEED)) {
+		error = remapError();
+		return error;
+	}
+	return 0;
+#else
+	error = ENOSYS;
+	return ENOSYS;
 #endif
 }
 
-void fsys::seek(offset_t pos)
+int fsys::seek(offset_t pos)
 {
 	unsigned long rpos = pos;
 	int mode = SEEK_SET;
@@ -684,8 +705,11 @@ void fsys::seek(offset_t pos)
 		rpos = 0;
 		mode = SEEK_END;
 	}
-	if(lseek(fd, rpos, mode) == ~0l)
+	if(lseek(fd, rpos, mode) == ~0l) {
 		error = remapError();
+		return error;
+	}
+	return 0;
 }
 
 #endif
